@@ -30,6 +30,10 @@
 
 #include "nm_log.h"
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #define NM_LOG_FILE "/tmp/conn_manager_log"
 
 static gint log_file = 0;
