@@ -28,6 +28,8 @@
 #include <glib/gi18n.h>
 #include <string.h>
 #include <glib.h>
+
+#include <libintl.h>
 #include <locale.h>
 
 
@@ -73,8 +75,8 @@ static void nm_main_dialog_finalize   (GObject *);
 static void nm_main_dialog_create_tree_view (NmMainDialog *);
 static void nm_main_dialog_add_widget (NmMainDialog *, GtkTreeView *, gchar *, NmConnWidget *,
                                         gboolean);
-static void nm_main_dialog_run_apply (NmMainDialog *);
-static void nm_main_dialog_run_save (NmMainDialog *);
+static gboolean nm_main_dialog_run_apply (NmMainDialog *);
+static gboolean nm_main_dialog_run_save (NmMainDialog *);
 static void nm_main_dialog_selection_changed (GtkTreeSelection *, gpointer);
 static void nm_main_dialog_tool_selection_changed (GtkTreeSelection *, gpointer);
 static NmConnWidget* nm_main_dialog_get_selected (NmMainDialog *);
@@ -172,7 +174,7 @@ nm_main_dialog_init (NmMainDialog *self)
     priv = NM_MAIN_DIALOG_GET_PRIVATE (self);
 
     /* Initialise the locale stuff */
-    setlocale ( LC_MESSAGES, "" );
+    setlocale ( LC_ALL, "" );
     bindtextdomain ( GETTEXT_PACKAGE, "/usr/share/locale" );
     bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
     textdomain ( GETTEXT_PACKAGE );
@@ -421,7 +423,7 @@ nm_main_dialog_add_widget (NmMainDialog *self, GtkTreeView *treeview, gchar *nam
     gtk_tree_store_set (GTK_TREE_STORE (model), &iter,
                          CONNECTION_NAME_COLUMN, name,
                          CONNECTION_WIDGET_COLUMN, widget, -1);
-
+    
     if (is_default) {
 
         gtk_tree_selection_select_iter
@@ -436,6 +438,7 @@ nm_main_dialog_run (NmMainDialog *self, int caller)
     NmMainDialogPrivate *priv = NM_MAIN_DIALOG_GET_PRIVATE (self);
     gint ret;
     gboolean done = FALSE;
+    gboolean saved = FALSE;
 
     /* Do not show the advanced button from the status menu*/
     g_debug("[%s] - caller: %d", __FUNCTION__, caller);
@@ -472,9 +475,12 @@ nm_main_dialog_run (NmMainDialog *self, int caller)
 
             case GTK_RESPONSE_OK:
 
-                nm_main_dialog_run_save (self);
-                hildon_banner_show_information (NULL, NULL,
-                                    "Environment saved successfully!");
+                saved = nm_main_dialog_run_save (self);
+                if (saved) {
+                    hildon_banner_show_information (NULL, NULL,
+                                    "Environment saved successfully!");                   
+                }
+
 #ifdef FREMANTLE
                 done = TRUE;
 #endif                
@@ -501,7 +507,7 @@ nm_main_dialog_run (NmMainDialog *self, int caller)
     }
 }
 
-static void
+static gboolean
 nm_main_dialog_run_apply (NmMainDialog *self)
 {
     NmMainDialogPrivate *priv = NM_MAIN_DIALOG_GET_PRIVATE (self);
@@ -509,7 +515,10 @@ nm_main_dialog_run_apply (NmMainDialog *self)
     // Set the current combobox to the active env
     gchar *env = gtk_combo_box_get_active_text (GTK_COMBO_BOX(priv->advanced_combo_box));
     nm_environment_manager_set_active(env);
-
+    
+    if (!nm_wlan_setup_is_valid(priv->wlansetup)) {
+        return FALSE;
+    }
     
     /* Apply network */
     if (!nm_usb_setup_apply_changes (NM_CONN_WIDGET(priv->usbsetup))) {
@@ -556,14 +565,12 @@ nm_main_dialog_run_apply (NmMainDialog *self)
                                         _("SAMBA settings error!"));
     }
 #endif
-    
-#ifdef FREMANTLE    
+     
     if (!nm_vnc_setup_apply_changes (NM_CONN_WIDGET(priv->vncsetup))) {
 
         hildon_banner_show_information(GTK_WIDGET (self), NULL,
                                         _("VNC settings error!"));
     }
-#endif
     
     gchar message[80];
     sprintf(message, _("Environment %s applied successfully"), env);
@@ -571,15 +578,21 @@ nm_main_dialog_run_apply (NmMainDialog *self)
     hildon_banner_show_information(GTK_WIDGET (self), NULL, message);
 
     g_free(env);
+    
+    return TRUE;
 }
 
-static void 
+static gboolean 
 nm_main_dialog_run_save (NmMainDialog *self) 
 {
     g_debug("[%s]", __FUNCTION__);
     
     NmMainDialogPrivate *priv = NM_MAIN_DIALOG_GET_PRIVATE (self);
-    
+
+    if (!nm_wlan_setup_is_valid(priv->wlansetup)) {
+        return FALSE;
+    }   
+
     nm_usb_setup_save_changes(NM_USB_SETUP(priv->usbsetup));
     nm_bt_setup_save_changes(NM_BT_SETUP(priv->btsetup));
     nm_wlan_setup_save_changes(NM_WLAN_SETUP(priv->wlansetup));
@@ -588,13 +601,11 @@ nm_main_dialog_run_save (NmMainDialog *self)
     nm_sbrsh_setup_save_changes(NM_SBRSH_SETUP(priv->sbrshsetup));
     nm_unfs_setup_save_changes(NM_UNFS_SETUP(priv->unfssetup));
 #ifdef DIABLO
-    nm_samba_setup_save_changes(NM_UNFS_SETUP(priv->sambasetup));
+    nm_samba_setup_save_changes(NM_SAMBA_SETUP(priv->sambasetup));
 #endif
-#ifdef FREMANTLE
     nm_vnc_setup_save_changes(NM_VNC_SETUP(priv->vncsetup));
-#endif
-
 
+    return TRUE;
 }
 
 static void
@@ -1151,14 +1162,14 @@ nm_main_dialog_setup_tool_manager (NmMainDialog *self)
 #endif
 
     priv->vncsetup = nm_vnc_setup_new (priv->env);
-#ifdef FREMANTLE
+
     nm_main_dialog_add_widget (self, GTK_TREE_VIEW(priv->tool_treeview), _("X11VNC"),
                                 NM_CONN_WIDGET (priv->vncsetup), FALSE);
     g_signal_connect (G_OBJECT (priv->vncsetup),
                        NM_CONN_WIDGET_SETTINGS_CHANGED,
                        G_CALLBACK (nm_main_dialog_settings_changed), self);
     nm_vnc_setup_fill_widget(NM_VNC_SETUP(priv->vncsetup));
-#endif
+
 
     priv->sbrshsetup = nm_sbrsh_setup_new (priv->env);
     nm_main_dialog_add_widget (self, GTK_TREE_VIEW(priv->tool_treeview), _("SBRSH"),
@@ -1178,10 +1189,10 @@ nm_main_dialog_setup_tool_manager (NmMainDialog *self)
     gtk_box_pack_start (GTK_BOX (priv->advanced_tool_manager_tab), priv->sambasetup,
                          FALSE, TRUE, 0);
 #endif
-#ifdef FREMANTLE
+
     gtk_box_pack_start (GTK_BOX (priv->advanced_tool_manager_tab), priv->vncsetup,
                          FALSE, TRUE, 0);
-#endif
+
 
     gtk_box_pack_start (GTK_BOX (priv->advanced_tool_manager_tab), priv->sbrshsetup,
                          FALSE, TRUE, 0);
