@@ -4,6 +4,10 @@
 
 #include "nm_ifaces_utils.h"
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #define NM_IFACES_APP_ARGC              5
 #define NM_IFACES_APP_OP_USB            "usb"
 #define NM_IFACES_APP_OP_BT             "bluetooth"
